@@ -588,6 +588,7 @@ def require_dataset(dataset, check_installed=True, purpose=None):
 # New helpers, courtesy of datalad-revolution.
 
 
+# note: not thread safe if threads chdir - uses getpwd
 def resolve_path(path, ds=None, ds_resolved=None):
     """Resolve a path specification (against a Dataset location)
 
@@ -626,6 +627,7 @@ def resolve_path(path, ds=None, ds_resolved=None):
         ds = ds_resolved or require_dataset(
             ds, check_installed=False, purpose='path resolution')
     out = []
+    pwd_parts = None  # get it upon first use but only once
     for p in ensure_list(path):
         if ds is None or not got_ds_instance:
             # no dataset at all or no instance provided -> CWD is always the reference
@@ -657,7 +659,8 @@ def resolve_path(path, ds=None, ds_resolved=None):
             # ALGORITHM: match any number of leading '..' path components
             # and shorten the PWD by that number
             # NOT using ut.Path.cwd(), because it has symlinks resolved!!
-            pwd_parts = ut.Path(getpwd()).parts
+            if not pwd_parts:
+                pwd_parts = ut.Path(getpwd()).parts
             path_parts = p.parts
             leading_parents = 0
             for pp in p.parts:
