@@ -10,13 +10,15 @@
 
 """
 
-from datalad.tests.utils import known_failure_v6
-
+import gc
+import json
 import logging
-from functools import partial
-from glob import glob
 import os
 import re
+import sys
+
+from functools import partial
+from glob import glob
 from os import mkdir
 from os.path import (
     join as opj,
@@ -27,14 +29,15 @@ from os.path import (
     exists,
 )
 from shutil import copyfile
-from datalad.tests.utils import assert_not_is_instance
-
 
 from urllib.parse import urljoin
 from urllib.parse import urlsplit
 
 from unittest.mock import patch
-import gc
+
+from datalad import (
+    cfg as dl_cfg,
+)
 
 from datalad.cmd import (
     GitWitlessRunner,
@@ -62,6 +65,7 @@ from datalad.tests.utils import (
     assert_is_instance,
     assert_not_equal,
     assert_not_in,
+    assert_not_is_instance,
     assert_raises,
     assert_re_in,
     assert_repo_status,
@@ -81,6 +85,7 @@ from datalad.tests.utils import (
     ok_file_has_content,
     ok_file_under_git,
     ok_git_config_not_empty,
+    on_travis,
     serve_path_via_http,
     set_annex_version,
     skip_if,
@@ -113,7 +118,6 @@ from datalad.support.exceptions import (
 )
 
 from datalad.support.gitrepo import GitRepo
-from datalad import cfg as dl_cfg
 
 # imports from same module:
 from datalad.support.annexrepo import (
@@ -1445,7 +1449,7 @@ def test_annex_drop(src, dst):
     with assert_raises(CommandError) as e:
         ar.drop('somefile.txt')
     # CommandError has to pull the errors from the JSON record 'note'
-    assert_in('necessary copies', str(e.exception))
+    assert_in('necessary cop', str(e.exception))
 
     with assert_raises(CommandError) as e:
         ar._call_annex_records(['fsck', '-N', '3'])
@@ -2193,6 +2197,61 @@ def test_annexjson_protocol(path):
     assert_not_in('errors from JSON records', str(e.exception))
 
 
+@with_tempfile
+def test_annexjson_protocol_long(path):
+    records = [
+        {"k": "v" * 20},
+        # Value based off of
+        # Lib.asyncio.unix_events._UnixReadPipeTransport.max_size.
+        {"k": "v" * 256 * 1024},
+        # and tiny ones in between should not be lost
+        {"k": "v"},
+        # even a much larger one - we should handle as well
+        {"k": "v" * 256 * 1024 * 5},
+    ]
+    with open(path, 'w') as f:
+        for record in records:
+            print("print(%r);" % json.dumps(record), file=f)
+    runner = GitWitlessRunner()
+    res = runner.run(
+        [sys.executable, path],
+        protocol=AnnexJsonProtocol
+    )
+    eq_(res['stdout'], '')
+    eq_(res['stderr'], '')
+    eq_(res['stdout_json'], records)
+
+
+def test_annexjson_protocol_incorrect():
+    yield check_annexjson_protocol_incorrect, ''
+    yield check_annexjson_protocol_incorrect, ', end=""'
+
+
+@with_tempfile
+def check_annexjson_protocol_incorrect(print_opt, path):
+    # Test that we still log some incorrectly formed JSON record
+    bad_json = '{"I": "am wrong,}'
+    with open(path, 'w') as f:
+        print("print(%r%s);" % (bad_json, print_opt), file=f)
+    runner = GitWitlessRunner()
+    with swallow_logs(new_level=logging.ERROR) as cml:
+        res = runner.run(
+            [sys.executable, path],
+            protocol=AnnexJsonProtocol
+        )
+        cml.assert_logged(
+            msg=".*[rR]eceived undecodable JSON output",
+            level="ERROR",
+            regex=True)
+    # only error logged and nothing returned
+    eq_(res['stdout'], '')
+    eq_(res['stderr'], '')
+    eq_(res['stdout_json'], [])
+
+# see https://github.com/datalad/datalad/pull/5400 for troubleshooting
+# for stalling with unlock=False, and then with unlock=True it took >= 300 sec
+# https://github.com/datalad/datalad/pull/5433#issuecomment-784470028
+@skip_if(on_travis and 'nfs' in os.getenv('TMPDIR', ''))  # TODO. stalls
 # http://git-annex.branchable.com/bugs/cannot_commit___34__annex_add__34__ed_modified_file_which_switched_its_largefile_status_to_be_committed_to_git_now/#comment-bf70dd0071de1bfdae9fd4f736fd1ec
 # https://github.com/datalad/datalad/issues/1651
 @known_failure_githubci_win
