@@ -10,16 +10,25 @@
 """
 
 import os
+import signal
 import sys
 
+from pathlib import Path
+from time import (
+    sleep,
+    time,
+)
+
 from datalad.tests.utils import (
     assert_cwd_unchanged,
     assert_in,
     assert_raises,
     eq_,
+    integration,
     OBSCURE_FILENAME,
     ok_,
     ok_file_has_content,
+    SkipTest,
     with_tempfile,
 )
 from datalad.cmd import (
@@ -27,7 +36,10 @@ from datalad.cmd import (
     WitlessRunner as Runner,
     StdOutCapture,
 )
-from datalad.utils import Path
+from datalad.utils import (
+    on_windows,
+    Path,
+)
 from datalad.support.exceptions import CommandError
 
 
@@ -44,8 +56,8 @@ def py2cmd(code):
 @with_tempfile
 def test_runner(tempfile):
     runner = Runner()
-    content = 'Testing äöü東 real run'
-    cmd = ['sh', '-c', 'echo %s > %r' % (content, tempfile)]
+    content = 'Testing real run' if on_windows else 'Testing äöü東 real run' 
+    cmd = 'echo %s > %s' % (content, tempfile)
     res = runner.run(cmd)
     # no capture of any kind, by default
     ok_(not res['stdout'])
@@ -147,3 +159,71 @@ def test_runner_parametrized_protocol():
         value=b'5',
     )
     eq_(res['stdout'], '5')
+
+
+@integration  # ~3 sec
+@with_tempfile(mkdir=True)
+@with_tempfile()
+def test_asyncio_loop_noninterference1(path1, path2):
+    if on_windows and sys.version_info < (3, 8):
+        raise SkipTest(
+            "get_event_loop() raises "
+            "RuntimeError: There is no current event loop in thread 'MainThread'.")
+    # minimalistic use case provided by Dorota
+    import datalad.api as dl
+    src = dl.create(path1)
+    reproducer = src.pathobj/ "reproducer.py"
+    reproducer.write_text(f"""\
+import asyncio
+asyncio.get_event_loop()
+import datalad.api as datalad
+ds = datalad.clone(path=r'{path2}', source=r"{path1}")
+loop = asyncio.get_event_loop()
+assert loop
+# simulate outside process closing the loop
+loop.close()
+# and us still doing ok
+ds.status()
+""")
+    Runner().run([sys.executable, str(reproducer)])  # if Error -- the test failed
+
+
+@with_tempfile
+def test_asyncio_forked(temp):
+    # temp will be used to communicate from child either it succeeded or not
+    temp = Path(temp)
+    runner = Runner()
+    import os
+    try:
+        pid = os.fork()
+    except BaseException as exc:
+        # .fork availability is "Unix", and there are cases where it is "not supported"
+        # so we will just skip if no forking is possible
+        raise SkipTest(f"Cannot fork: {exc}")
+    # if does not fail (in original or in a fork) -- we are good
+    if sys.version_info < (3, 8) and pid != 0:
+        # for some reason it is crucial to sleep a little (but 0.001 is not enough)
+        # in the master process with older pythons or it takes forever to make the child run
+        sleep(0.1)
+    try:
+        runner.run([sys.executable, '--version'], protocol=StdOutCapture)
+        if pid == 0:
+            temp.write_text("I rule")
+    except:
+        if pid == 0:
+            temp.write_text("I suck")
+    if pid != 0:
+       # parent: look after the child
+       t0 = time()
+       try:
+           while not temp.exists() or temp.stat().st_size < 6:
+               if time() - t0 > 5:
+                   raise AssertionError("Child process did not create a file we expected!")
+       finally:
+           # kill the child
+           os.kill(pid, signal.SIGTERM)
+       # see if it was a good one
+       eq_(temp.read_text(), "I rule")
+    else:
+       # sleep enough so parent just kills me the kid before I continue doing bad deeds
+       sleep(10)
